"""high_score.py - High score demo for sqlnub module

Note: Run this demo three times to see Gumm climb to the top. A file named
high_scores_demo.db will be created. You may remove this file when finished
playing with the demo.
"""

from sqlnub import SqlNub


class GameDB(SqlNub):

    def __init__(self, filename):
        # open the db
        SqlNub.__init__(self, filename)

        # if Scores table is absent, create it
        if 'Scores' not in self.get_table_names():
            self.create_table(
                'Scores', (('player', 'TEXT PRIMARY KEY'), ('score', 'INT')))
            print('Created Scores table...')

    def save_score(self, player, score):
        cursor = self.conn.execute(
            "update Scores set score=? where player=?", (score, player))
        if cursor.rowcount == 0:
            self.conn.execute(
                "insert into Scores values(?, ?)", (player, score))
        self.commit()

    def get_score(self, player):
        cursor = self.conn.execute(
            "select score from Scores where player=?", (player,))
        return cursor.fetchone()

    def get_scores(self):
        return self.conn.execute(
            "SELECT * FROM Scores ORDER BY score DESC").fetchall()

    def print_scores(self):
        print('{0:8s}    {1}'.format('Player', 'Score'))
        print('{0:8s}    {1}'.format('------', '-----'))
        for row in self.get_scores():
            print('{0[0]:8s}    {0[1]}'.format(row))


if __name__ == '__main__':

    # open the DB; if it is empty put some scores in it
    db = GameDB('high_scores_demo.db')
    scores = db.get_scores()
    if not scores:
        db.save_score('Doug', 1)
        db.save_score('Digg', 2)
        db.save_score('Gumm', 0)

    # see Gumm's starting rank
    print('')
    print('Scores before:')
    db.print_scores()

    # get Gumm's score if it exists; bump it up
    row = db.get_score('Gumm')
    score = row['score'] if row else 0
    score += 1

    # save Gumm's new score
    db.save_score('Gumm', score)

    # see Gumm's new rank
    print('')
    print('Scores after:')
    db.print_scores()
